@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 
-# $Id: lamdaemon.pl,v 1.61 2011/05/07 08:04:45 gruberroland Exp $
+# $Id: lamdaemon.pl,v 1.63 2011/12/08 17:20:22 gruberroland Exp $
 #
 #  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
 #  Copyright (C) 2003 - 2006  Tilo Lutz
@@ -297,15 +297,17 @@ sub manageQuotas {
 	@quota_temp1 = split (':', $vals[4]);
 	$group=0;
 	$i=0;
-	while ($quota_temp1[$i]) {
-		$j=0;
-		@temp = split (',', $quota_temp1[$i]);
-			while ($temp[$j]) {
-				$quota[$i][$j] = $temp[$j];
+	foreach my $quota_element (@quota_temp1) {
+		if (length ($quota_element) >= 2) {
+			@temp = split (',', $quota_element);
+			$j=0;
+			foreach my $temp_element (@temp) {
+				$quota[$i][$j] = $temp_element;
 				$j++;
-				}
+			}
 			$i++;
 		}
+	}
 	if ($vals[3] eq 'user') { $group=false; }
 	else {
 		$group=1;
@@ -348,10 +350,11 @@ sub setQuotas {
 	($<, $>) = ($>, $<); # Get root privileges
 	while ($quota[$i][0]) {
 		$dev = Quota::getqcarg($quota[$i][0]);
+		last if ($dev eq '');
 		$return = Quota::setqlim($dev,$user[2],$quota[$i][1],$quota[$i][2],$quota[$i][3],$quota[$i][4],1,$group);
 		if ($return == -1) {
 				$return = "ERROR,Lamdaemon ($hostname),Unable to set quota!";
-				logMessage(LOG_ERR, "Unable to set quota for $user[0].");
+				logMessage(LOG_ERR, "Unable to set quota for $user[0] on " . $quota[$i][0] . ".");
 		}
 		else {
 			logMessage(LOG_INFO, "Set quota for $user[0].");
