@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: edit.php,v 1.14 2010/01/13 19:26:25 gruberroland Exp $
+$Id: edit.php,v 1.15 2010/08/21 09:43:51 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Tilo Lutz
@@ -68,8 +68,7 @@ if (isset($_GET['DN'])) {
 		for ($i=0; $i<sizeof($result); $i++) {
 			call_user_func_array("StatusMessage", $result[$i]);
 		}
-		echo "</body>\n";
-		echo "</html>\n";
+		include '../main_footer.php';
 		die();
 	}
 }
