@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmain.php,v 1.131 2011/08/23 19:04:35 gruberroland Exp $
+$Id: confmain.php,v 1.135 2012/03/13 21:02:37 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2011  Roland Gruber
+  Copyright (C) 2003 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ if (isset($_POST['passwd'])) $passwd = $_POST['passwd'];
 
 // check if password was entered
 // if not: load login page
-if (!isset($passwd) && !isset($_SESSION['conf_isAuthenticated'])) {
+if (!isset($passwd) && !(isset($_SESSION['conf_isAuthenticated']) && isset($_SESSION['conf_config']))) {
 	$_SESSION['conf_message'] = _("No password was entered!");
 	/** go back to login if password is empty */
 	metaRefresh('conflogin.php');
@@ -83,6 +83,10 @@ if (isset($_POST['cancelSettings'])) {
 }
 
 $errorsToDisplay = array();
+if (isset($_SESSION['conf_messages']) && is_array($_SESSION['conf_messages'])) {
+	$errorsToDisplay = array_merge($errorsToDisplay, $_SESSION['conf_messages']);
+	unset($_SESSION['conf_messages']);
+}
 
 // check if button was pressed and if we have to save the settings or go to another tab
 if (isset($_POST['saveSettings']) || isset($_POST['editmodules'])
@@ -156,7 +160,7 @@ foreach ($jsFiles as $jsEntry) {
 <?php
 
 if (!$conf->isWritable()) {
-	StatusMessage('WARN', 'The config file is not writable.', 'Your changes cannot be saved until you make the file writable for the webserver user.');
+	StatusMessage('WARN', _('The config file is not writable.'), _('Your changes cannot be saved until you make the file writable for the webserver user.'));
 	echo "<br>";
 }
 
@@ -358,6 +362,12 @@ $securitySettingsContent->addElement($searchSuffixInput, true);
 $searchFilterInput = new htmlTableExtendedInputField(_("LDAP filter"), 'loginSearchFilter', $conf->getLoginSearchFilter(), '221');
 $searchFilterInput->setRequired(true);
 $securitySettingsContent->addElement($searchFilterInput, true);
+// login search bind user
+$securitySettingsContent->addElement(new htmlTableExtendedInputField(_("Bind user"), 'loginSearchDN', $conf->getLoginSearchDN(), '224'), true);
+// login search bind password
+$searchPasswordInput = new htmlTableExtendedInputField(_("Bind password"), 'loginSearchPassword', $conf->getLoginSearchPassword(), '224');
+$searchPasswordInput->setIsPassword(true);
+$securitySettingsContent->addElement($searchPasswordInput, true);
 // HTTP authentication
 $securitySettingsContent->addElement(new htmlTableExtendedInputCheckbox('httpAuthentication', ($conf->getHttpAuthentication() == 'true'), _('HTTP authentication'), '223', true), true);
 $securitySettingsContent->addElement(new htmlSpacer(null, '10px'), true);
@@ -414,6 +424,9 @@ function checkInput() {
 		$errors[] = array("ERROR", _("Server address is invalid!"));
 	}
 	$conf->setUseTLS($_POST['useTLS']);
+	if ((strpos($_POST['serverurl'], 'ldaps://') !== false) && ($_POST['useTLS'] == 'yes')) {
+		$errors[] = array("ERROR", _('You cannot use SSL and TLS encryption at the same time. Please use either "ldaps://" or TLS.'));
+	}
 /*	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
 		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
 	}*/
@@ -421,10 +434,10 @@ function checkInput() {
 	if (isLAMProVersion()) {
 		$conf->setAccessLevel($_POST['accessLevel']);
 		if (!$conf->setLamProMailFrom($_POST['pwdResetMail_from'])) {
-			$errors[] = array("ERROR", _("From address for password mails is invalid."), $_POST['pwdResetMail_from']);
+			$errors[] = array("ERROR", _("From address for password mails is invalid."), htmlspecialchars($_POST['pwdResetMail_from']));
 		}
 		if (!$conf->setLamProMailReplyTo($_POST['pwdResetMail_replyTo'])) {
-			$errors[] = array("ERROR", _("Reply-to address for password mails is invalid."), $_POST['pwdResetMail_replyTo']);
+			$errors[] = array("ERROR", _("Reply-to address for password mails is invalid."), htmlspecialchars($_POST['pwdResetMail_replyTo']));
 		}
 		$conf->setLamProMailSubject($_POST['pwdResetMail_subject']);
 		if (isset($_POST['pwdResetMail_isHTML']) && ($_POST['pwdResetMail_isHTML'] == 'on')) {
@@ -445,6 +458,10 @@ function checkInput() {
 	$conf->setLoginMethod($_POST['loginMethod']);
 	$conf->setLoginSearchFilter($_POST['loginSearchFilter']);
 	$conf->setLoginSearchSuffix($_POST['loginSearchSuffix']);
+	if (!$conf->setLoginSearchDN($_POST['loginSearchDN'])) {
+		$errors[] = array("ERROR", _("Please enter a valid bind user."));
+	}
+	$conf->setLoginSearchPassword($_POST['loginSearchPassword']);
 	if (isset($_POST['httpAuthentication']) && ($_POST['httpAuthentication'] == 'on')) {
 		$conf->setHttpAuthentication('true');
 	}
