@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmodules.php,v 1.41 2010/09/13 20:05:58 gruberroland Exp $
+$Id: confmodules.php,v 1.44 2011/01/08 19:44:08 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2010  Roland Gruber
+  Copyright (C) 2004 - 2011  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -138,13 +138,6 @@ for ($i = 0; $i < sizeof($errorsToDisplay); $i++) call_user_func_array('StatusMe
 
 echo ("<form action=\"confmodules.php\" method=\"post\">\n");
 
-echo '<div style="text-align: right;">';
-echo "<button id=\"saveButton\" name=\"saveSettings\" type=\"submit\">" . _('Save') . "</button>";
-echo "&nbsp;";
-echo "<button id=\"cancelButton\" name=\"cancelSettings\" type=\"submit\">" . _('Cancel') . "</button>";
-echo "<br><br>\n";
-echo '</div>';
-
 // hidden submit buttons which are clicked by tabs
 echo "<div style=\"display: none;\">\n";
 	echo "<input name=\"generalSettingsButton\" type=\"submit\" value=\" \">";
@@ -157,11 +150,11 @@ echo "</div>\n";
 echo '<div class="ui-tabs ui-widget ui-widget-content ui-corner-all">';
 
 echo '<ul class="ui-tabs-nav ui-helper-reset ui-helper-clearfix ui-widget-header ui-corner-all">';
-echo '<li id="generalSettingsButton" class="ui-state-default ui-corner-top">';
+echo '<li id="generalSettingsButton" class="ui-state-default ui-corner-top" onmouseover="jQuery(this).addClass(\'tabs-hover\');" onmouseout="jQuery(this).removeClass(\'tabs-hover\');">';
 	echo '<a href="#" onclick="document.getElementsByName(\'generalSettingsButton\')[0].click();"><img src="../../graphics/tools.png" alt=""> ';
 	echo _('General settings') . '</a>';
 echo '</li>';
-echo '<li id="edittypes" class="ui-state-default ui-corner-top">';
+echo '<li id="edittypes" class="ui-state-default ui-corner-top" onmouseover="jQuery(this).addClass(\'tabs-hover\');" onmouseout="jQuery(this).removeClass(\'tabs-hover\');">';
 	echo '<a href="#" onclick="document.getElementsByName(\'edittypes\')[0].click();"><img src="../../graphics/gear.png" alt=""> ';
 	echo _('Account types') . '</a>';
 echo '</li>';
@@ -169,7 +162,7 @@ echo '<li id="editmodules" class="ui-state-default ui-corner-top">';
 	echo '<a href="#" onclick="document.getElementsByName(\'editmodules\')[0].click();"><img src="../../graphics/modules.png" alt=""> ';
 	echo _('Modules') . '</a>';
 echo '</li>';
-echo '<li id="moduleSettings" class="ui-state-default ui-corner-top">';
+echo '<li id="moduleSettings" class="ui-state-default ui-corner-top" onmouseover="jQuery(this).addClass(\'tabs-hover\');" onmouseout="jQuery(this).removeClass(\'tabs-hover\');">';
 	echo '<a href="#" onclick="document.getElementsByName(\'moduleSettings\')[0].click();"><img src="../../graphics/modules.png" alt=""> ';
 	echo _('Module settings') . '</a>';
 echo '</li>';
@@ -181,20 +174,18 @@ echo '</ul>';
 jQuery(document).ready(function() {
 	jQuery('#editmodules').addClass('ui-tabs-selected');
 	jQuery('#editmodules').addClass('ui-state-active');
-	jQuery('#saveButton').button({
-        icons: {
-      	  primary: 'saveButton'
-    	}
-	});
-	jQuery('#cancelButton').button({
-        icons: {
-    	  primary: 'cancelButton'
-  	}
+	jQuery('#editmodules').addClass('userlist-bright');
+	// set common width for select boxes
+	var maxWidth = 0;
+	jQuery("select").each(function(){
+		if (jQuery(this).width() > maxWidth)
+		maxWidth = jQuery(this).width();   
 	});
+	jQuery("select").width(maxWidth);
 });
 </script>
 
-<div class="ui-tabs-panel ui-widget-content ui-corner-bottom">
+<div class="ui-tabs-panel ui-widget-content ui-corner-bottom userlist-bright">
 <?php
 
 
@@ -203,21 +194,34 @@ for ($i = 0; $i < sizeof($types); $i++) {
 	$account_list[] = array($types[$i], getTypeAlias($types[$i]));
 }
 
+$container = new htmlTable();
 for ($i = 0; $i < sizeof($account_list); $i++) {
-	config_showAccountModules($account_list[$i][0], $account_list[$i][1]);
+	config_showAccountModules($account_list[$i][0], $account_list[$i][1], $container);
 }
 
+$legendContainer = new htmlTable();
+$legendContainer->addElement(new htmlOutputText("(*) " . _("Base module")));
+$legendContainer->addElement(new htmlHelpLink('237'));
+$container->addElement($legendContainer);
+$container->addElement(new htmlHiddenInput('postAvailable', 'yes'));
 
-echo "<p>\n";
-echo "(*) " . _("Base module");
-// help link
-echo "&nbsp;";
-printHelpLink(getHelp('', '237'), '237');
-echo "<br></p>\n";
+$tabindex = 1;
+parseHtml(null, $container, array(), false, $tabindex, 'user');
 
-echo "<input type=\"hidden\" name=\"postAvailable\" value=\"yes\">\n";
+echo "</div></div>";
 
-echo ("</div></div></form>\n");
+$buttonContainer = new htmlTable();
+$buttonContainer->addElement(new htmlSpacer(null, '10px'), true);
+$saveButton = new htmlButton('saveSettings', _('Save'));
+$saveButton->setIconClass('saveButton');
+$buttonContainer->addElement($saveButton);
+$cancelButton = new htmlButton('cancelSettings', _('Cancel'));
+$cancelButton->setIconClass('cancelButton');
+$buttonContainer->addElement($cancelButton, true);
+$buttonContainer->addElement(new htmlSpacer(null, '10px'), true);
+parseHtml(null, $buttonContainer, array(), false, $tabindex, 'user');
+
+echo "</form>\n";
 echo "</body>\n";
 echo "</html>\n";
 
@@ -227,8 +231,9 @@ echo "</html>\n";
 *
 * @param string $scope account type
 * @param string $title title for module selection (e.g. "User modules")
+* @param htmlTable $container meta HTML container
 */
-function config_showAccountModules($scope, $title) {
+function config_showAccountModules($scope, $title, &$container) {
 	$conf = &$_SESSION['conf_config'];
 	$typeSettings = $conf->get_typeSettings();
 	// account modules
@@ -246,71 +251,70 @@ function config_showAccountModules($scope, $title) {
 	}
 	natcasesort($sortedAvailable);
 
-	// show account modules
-	$icon = '<img alt="' . $scope . '" src="../../graphics/' . $scope . '.png">&nbsp;';
-	echo "<fieldset class=\"" . $scope . "edit\"><legend>$icon<b>" . $title . "</b></legend><br>\n";
-	echo "<table border=0 width=\"100%\">\n";
-		// select boxes
-		echo "<tr>\n";
-			echo "<td width=\"5%\"></td>\n";
-			echo "<td width=\"40%\">\n";
-				echo "<fieldset class=\"" . $scope . "edit\">\n";
-					echo "<legend>" . _("Selected modules") . "</legend><br>\n";
-					echo "<select class=\"" . $scope . "edit\" name=\"" . $scope . "_selected[]\" size=5 multiple>\n";
-						for ($i = 0; $i < sizeof($selected); $i++) {
-							if (in_array($selected[$i], $available)) {  // selected modules must be available
-								if (is_base_module($selected[$i], $scope)) {  // mark base modules
-									echo "<option value=\"" . $selected[$i] . "\">";
-									echo getModuleAlias($selected[$i], $scope) . " (" . $selected[$i] .  ")(*)";
-									echo "</option>\n";
-								}
-								else {
-									echo "<option value=\"" . $selected[$i] . "\">";
-									echo getModuleAlias($selected[$i], $scope) . " (" . $selected[$i] .  ")";
-									echo "</option>\n";
-								}
-							}
-						}
-					echo "</select>\n";
-				echo "</fieldset>\n";
-			echo "</td>\n";
-			echo "<td width=\"10%\" align=\"center\">\n";
-				echo "<p>";
-					echo "<input type=submit title=\"" . _('Add') . "\" value=\" \" name=\"" . $scope . "_add\"" .
-					"style=\"background-image: url(../../graphics/back.gif);background-position: 2px center;background-repeat: no-repeat;width:24px;height:24px;background-color:transparent\">";
-					echo "<br>";
-					echo "<input type=submit title=\"" . _('Remove') . "\" value=\" \" name=\"" . $scope . "_remove\"" .
-					"style=\"background-image: url(../../graphics/forward.gif);background-position: 2px center;background-repeat: no-repeat;width:24px;height:24px;background-color:transparent\">";
-				echo "</p>\n";
-			echo "</td>\n";
-			echo "<td width=\"40%\">\n";
-				echo "<fieldset class=\"" . $scope . "edit\">\n";
-					echo "<legend>" . _("Available modules") . "</legend><br>\n";
-					echo "<select class=\"" . $scope . "edit\" name=\"" . $scope . "_available[]\" size=5 multiple>\n";
-						foreach ($sortedAvailable as $key => $value) {
-							if (! in_array($key, $selected)) {  // display non-selected modules
-								if (is_base_module($key, $scope)) {  // mark base modules
-									echo "<option value=\"" . $key . "\">";
-									echo $value . " (" . $key .  ")(*)";
-									echo "</option>\n";
-								}
-								else {
-									echo "<option value=\"" . $key . "\">";
-									echo $value . " (" . $key .  ")";
-									echo "</option>\n";
-								}
-							}
-						}
-					echo "</select>\n";
-				echo "</fieldset>\n";
-			echo "</td>\n";
-			echo "<td width=\"5%\"></td>\n";
-		echo "</tr>\n";
-	echo "</table>\n";
+	// build options for selected and available modules
+	$selOptions = array();
+	for ($i = 0; $i < sizeof($selected); $i++) {
+		if (in_array($selected[$i], $available)) {  // selected modules must be available
+			if (is_base_module($selected[$i], $scope)) {  // mark base modules
+				$selOptions[getModuleAlias($selected[$i], $scope) . " (" . $selected[$i] .  ")(*)"] = $selected[$i];
+			}
+			else {
+				$selOptions[getModuleAlias($selected[$i], $scope) . " (" . $selected[$i] .  ")"] = $selected[$i];
+			}
+		}
+	}
+	$availOptions = array();
+	foreach ($sortedAvailable as $key => $value) {
+		if (! in_array($key, $selected)) {  // display non-selected modules
+			if (is_base_module($key, $scope)) {  // mark base modules
+				$availOptions[$value . " (" . $key .  ")(*)"] = $key;
+			}
+			else {
+				$availOptions[$value . " (" . $key .  ")"] = $key;
+			}
+		}
+	}
 	
-	echo "</fieldset>\n";
-	
-	echo "<br>\n";
+	// add account module selection
+	$container->addElement(new htmlSubTitle($title, '../../graphics/' . $scope . '.png'), true);
+	$container->addElement(new htmlOutputText(_("Selected modules")));
+	// add/remove buttons
+	$buttonContainer = new htmlTable();
+	$buttonContainer->rowspan = 2;
+	if (sizeof($availOptions) > 0) {
+		$addButton = new htmlButton($scope . "_add", 'back.gif', true);
+		$addButton->setTitle(_('Add'));
+		$buttonContainer->addElement($addButton, true);
+	}
+	if (sizeof($selOptions) > 0) {
+		$remButton = new htmlButton($scope . "_remove", 'forward.gif', true);
+		$remButton->setTitle(_('Remove'));
+		$buttonContainer->addElement($remButton, true);
+	}
+	$container->addElement($buttonContainer);
+	$container->addElement(new htmlOutputText(_("Available modules")), true);
+	// selected modules
+	if (sizeof($selOptions) > 0) {
+		$selSelect = new htmlSelect($scope . '_selected', $selOptions, array(), 5);
+		$selSelect->setTransformSingleSelect(false);
+		$selSelect->setMultiSelect(true);
+		$selSelect->setHasDescriptiveElements(true);
+		$selSelect->setSortElements(false);
+		$container->addElement($selSelect);
+	}
+	else {
+		$container->addElement(new htmlOutputText(''));
+	}
+	// available modules
+	if (sizeof($availOptions) > 0) {
+		$availSelect = new htmlSelect($scope . "_available", $availOptions, array(), 5);
+		$availSelect->setTransformSingleSelect(false);
+		$availSelect->setHasDescriptiveElements(true);
+		$availSelect->setMultiSelect(true);
+		$container->addElement($availSelect, true);
+	}
+	// spacer to next account type
+	$container->addElement(new htmlSpacer(null, '30px'), true);
 }
 
 /**
