@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: mainmanage.php,v 1.26 2010/11/18 19:29:44 gruberroland Exp $
+$Id: mainmanage.php,v 1.28 2012/03/13 21:02:37 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2010  Roland Gruber
+  Copyright (C) 2003 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -90,9 +90,9 @@ if (isset($_POST['submit'])) {
 				continue;
 			}
 			// check each line
-			$ipRegex = '/^[0-9\\.\\*]+$/';
+			$ipRegex = '/^[0-9a-f\\.:\\*]+$/i';
 			if (!preg_match($ipRegex, $allowedHostsList[$i]) || (strlen($allowedHostsList[$i]) > 15)) {
-				$errors[] = sprintf(_("The IP address %s is invalid!"), str_replace('%', '%%', $allowedHostsList[$i]));
+				$errors[] = sprintf(_("The IP address %s is invalid!"), htmlspecialchars(str_replace('%', '%%', $allowedHostsList[$i])));
 			}
 		}
 		$allowedHosts = implode(",", $allowedHostsList);
@@ -239,7 +239,7 @@ $passwordTable = new htmlTable();
 $pwd1 = new htmlTableExtendedInputField(_("New master password"), 'masterpassword', '', '235');
 $pwd1->setIsPassword(true);
 $passwordTable->addElement($pwd1, true);
-$pwd2 = new htmlTableExtendedInputField(_("Reenter new master password"), 'masterpassword2', '');
+$pwd2 = new htmlTableExtendedInputField(_("Reenter password"), 'masterpassword2', '');
 $pwd2->setIsPassword(true);
 $passwordTable->addElement($pwd2, true);
 $passwordField = new htmlFieldset($passwordTable, _("Change master password"));
