@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: moduleSettings.php,v 1.14 2011/01/08 19:44:08 gruberroland Exp $
+$Id: moduleSettings.php,v 1.15 2012/02/27 17:00:49 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2009 - 2011  Roland Gruber
@@ -198,7 +198,7 @@ $old_options = $conf->get_moduleSettings();
 
 
 // display module boxes
-$tabindex = 0;
+$tabindex = 1;
 $modules = array_keys($options);
 $_SESSION['conf_types'] = array();
 for ($i = 0; $i < sizeof($modules); $i++) {
@@ -259,6 +259,10 @@ function checkInput() {
 		if ($_SESSION['conf_types'][$element] == "text") {
 			$options[$element] = array($_POST[$element]);
 		}
+		// text fields
+		elseif ($_SESSION['conf_types'][$element] == "text_obfuscated") {
+			$options[$element] = array(obfuscateText($_POST[$element]));
+		}
 		// checkboxes
 		elseif ($_SESSION['conf_types'][$element] == "checkbox") {
 			if (isset($_POST[$element]) && ($_POST[$element] == "on")) $options[$element] = array('true');
