@@ -1,9 +1,9 @@
 /**
 
-$Id: 500_lam.js,v 1.10 2011/08/23 19:05:05 gruberroland Exp $
+$Id: 500_lam.js,v 1.14 2012/03/10 15:35:49 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2011  Roland Gruber
+  Copyright (C) 2003 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -103,9 +103,16 @@ function listShowSettingsDialog(title, okText, cancelText) {
 
 function SubmitForm(id, e) {
 	if (e.keyCode == 13) {
+		if (e.preventDefault) {
+			e.preventDefault();
+		}
+		if (e.returnValue) {
+			e.returnValue = false;
+		}
 		document.getElementsByName(id)[0].click();
 		return false;
 	}
+	return true;
 }
 
 function addResizeHandler(item, min, max) {
@@ -157,12 +164,16 @@ function configLoginMethodChanged() {
 		jQuery('textarea[name=admins]').parent().parent().show();
 		jQuery('input[name=loginSearchSuffix]').parent().parent().hide();
 		jQuery('input[name=loginSearchFilter]').parent().parent().hide();
+		jQuery('input[name=loginSearchDN]').parent().parent().hide();
+		jQuery('input[name=loginSearchPassword]').parent().parent().hide();
 		jQuery('input[name=httpAuthentication]').parent().parent().hide();
 	}
 	else {
 		jQuery('textarea[name=admins]').parent().parent().hide();
 		jQuery('input[name=loginSearchSuffix]').parent().parent().show();
 		jQuery('input[name=loginSearchFilter]').parent().parent().show();
+		jQuery('input[name=loginSearchDN]').parent().parent().show();
+		jQuery('input[name=loginSearchPassword]').parent().parent().show();
 		jQuery('input[name=httpAuthentication]').parent().parent().show();
 	}
 }
@@ -259,11 +270,13 @@ function passwordHandleInput(random, ajaxURL) {
 	});
 	var pwd1 = jQuery('#passwordDialog').find('[name=newPassword1]').val();
 	var pwd2 = jQuery('#passwordDialog').find('[name=newPassword2]').val();
+	var forcePasswordChange = jQuery('input[name=lamForcePasswordChange]').attr('checked');
 	var pwdJSON = {
 		"modules": modules,
 		"password1": pwd1,
 		"password2": pwd2,
-		"random": random
+		"random": random,
+		"forcePasswordChange": forcePasswordChange
 	};
 	// make AJAX call
 	jQuery.post(ajaxURL, {jsonInput: pwdJSON}, function(data) {passwordHandleReply(data);}, 'json');
@@ -279,6 +292,9 @@ function passwordHandleReply(data) {
 		jQuery('#passwordDialogMessageArea').html("");
 		jQuery('#passwordDialog').dialog("close");
 		jQuery('#passwordMessageArea').html(data.messages);
+		if (data.forcePasswordChange) {
+			jQuery('#forcePasswordChangeOption').attr('checked', 'checked');
+		}
 	}
 	else {
 		jQuery('#passwordDialogMessageArea').html(data.messages);
@@ -305,6 +321,8 @@ function showConfirmationDialog(title, okText, cancelText, dialogDiv, formName)
 		buttons: buttonList,
 		width: 'auto'
 	});
+	/* reattach dialog to form */
+	jQuery('#' + dialogDiv).parent().appendTo(document.forms[formName]);
 }
 
 
