@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: deletelink.php,v 1.4 2010/08/21 09:43:51 gruberroland Exp $
+$Id: deletelink.php,v 1.6 2012/03/18 18:31:36 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2007 - 2010  Roland Gruber
@@ -45,13 +45,17 @@ setlanguage();
 // get account name and type
 $dn = $_GET['DN'];
 $type = $_GET['type'];
+if (!preg_match('/^[a-z0-9_]+$/i', $type)) {
+	logNewMessage(LOG_ERR, 'Invalid type: ' . $type);
+	die();
+}
 
 if (isset($dn) && isset($type)) {
 	$dn = str_replace("\\", '',$dn);
 	$dn = str_replace("'", '',$dn);
 	$_SESSION['delete_dn'] = array($dn);
 	// redirect to delete.php
-	metaRefresh("../delete.php?type=" . $type);
+	metaRefresh("../delete.php?type=" . htmlspecialchars($type));
 
 }
 else {
