@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: main.php,v 1.46 2010/11/23 21:23:25 gruberroland Exp $
+$Id: main.php,v 1.47 2011/05/19 16:14:49 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2010  Roland Gruber
+  Copyright (C) 2003 - 2011  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -60,7 +60,7 @@ else {
 		metaRefresh("lists/list.php?type=" . $types[0]);
 	}
 	else {
-		metaRefresh("tree/tree_view.php");
+		metaRefresh("tree/treeViewContainer.php");
 	}
 }
 ?>
