@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: massBuildAccounts.php,v 1.23 2011/02/13 11:46:52 gruberroland Exp $
+$Id: massBuildAccounts.php,v 1.27 2012/03/18 18:24:25 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2010  Roland Gruber
+  Copyright (C) 2004 - 2012  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -69,6 +69,9 @@ if (isset($_GET['showldif'])) {
 		unset($accounts[$i]['dn']);
 		$keys = array_keys($accounts[$i]);
 		for ($k = 0; $k < sizeof($keys); $k++) {
+			if (strpos($keys[$k], 'INFO.') === 0) {
+				continue;
+			}
 			if (is_array($accounts[$i][$keys[$k]])) {
 				for ($x = 0; $x < sizeof($accounts[$i][$keys[$k]]); $x++) {
 					echo $keys[$k] . ": " . $accounts[$i][$keys[$k]][$x] . "\n";
@@ -84,7 +87,8 @@ if (isset($_GET['showldif'])) {
 }
 
 include 'main_header.php';
-echo '<div class="' . $_POST['scope'] . 'list-bright smallPaddingContent">';
+$scope = htmlspecialchars($_POST['scope']);
+echo '<div class="' . $scope . 'list-bright smallPaddingContent">';
 
 $selectedModules = explode(',', $_POST['selectedModules']);
 if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
@@ -92,7 +96,7 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 	$data = array();  // input values without first row
 	$ids = array();  // <column name> => <column number for $data>
 	// get input fields from modules
-	$columns = getUploadColumns($_POST['scope'], $selectedModules);
+	$columns = getUploadColumns($scope, $selectedModules);
 	// read input file
 	$handle = fopen ($_FILES['inputfile']['tmp_name'], "r");
 	if (($head = fgetcsv($handle, 2000)) !== false ) { // head row
@@ -155,14 +159,15 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 	// if input data is invalid just display error messages (max 50)
 	if (sizeof($errors) > 0) {
 		for ($i = 0; $i < sizeof($errors); $i++) StatusMessage("ERROR", $errors[$i][0], $errors[$i][1]);
+		massPrintBackButton($scope, $selectedModules);
 	}
 	
 	// let modules build accounts
 	else {
-		$accounts = buildUploadAccounts($_POST['scope'], $data, $ids, $selectedModules);
+		$accounts = buildUploadAccounts($scope, $data, $ids, $selectedModules);
 		if ($accounts != false) {
-			$rdnList = getRDNAttributes($_POST['scope'], $selectedModules);
-			$suffix = $_SESSION['config']->get_Suffix($_POST['scope']);
+			$rdnList = getRDNAttributes($scope, $selectedModules);
+			$suffix = $_SESSION['config']->get_Suffix($scope);
 			// set DN
 			for ($i = 0; $i < sizeof($accounts); $i++) {
 				// check against list of possible RDN attributes
@@ -189,26 +194,45 @@ if ($_FILES['inputfile'] && ($_FILES['inputfile']['size'] > 0)) {
 				$_SESSION['mass_postActions'] = array();
 				$_SESSION['mass_data'] = $_SESSION['ldap']->encrypt(serialize($data));
 				$_SESSION['mass_ids'] = $ids;
-				$_SESSION['mass_scope'] = $_POST['scope'];
+				$_SESSION['mass_scope'] = $scope;
 				$_SESSION['mass_selectedModules'] = $selectedModules;
+				if (isset($_SESSION['mass_pdf'])) {
+					unset($_SESSION['mass_pdf']);
+				}
+				if (isset($_POST['createPDF']) && ($_POST['createPDF'] == 'on')) {
+					$_SESSION['mass_pdf']['structure'] = $_POST['pdfStructure'];
+					$_SESSION['mass_pdf']['counter'] = 0;
+					$_SESSION['mass_pdf']['file'] = '../tmp/lam_pdf' . $_SESSION['ldap']->new_rand() . '.zip';
+				}
+				else {
+					$_SESSION['mass_pdf']['structure'] = null;
+				}
 				// show links for upload and LDIF export
 				echo "<div class=\"title\">\n";
 				echo "<h2 class=\"titleText\">" . _("LAM has checked your input and is now ready to create the accounts.") . "</h2>\n";
 				echo "</div>";
 				echo "<p>&nbsp;</p>\n";
-					echo "<a href=\"massDoUpload.php\">" . _("Upload accounts to LDAP") . "</a>";
-					echo "&nbsp;&nbsp;&nbsp;&nbsp;";
-					echo "<a href=\"massBuildAccounts.php?showldif=true\">" . _("Show LDIF file") . "</a>";
+				echo "<a id=\"uploadLink\" href=\"massDoUpload.php\">" . _("Upload accounts to LDAP") . "</a>";
+				echo "&nbsp;&nbsp;&nbsp;&nbsp;";
+				echo "<a id=\"createLDIFLink\" href=\"massBuildAccounts.php?showldif=true\">" . _("Show LDIF file") . "</a>";
+				?>
+				<script type="text/javascript">
+				jQuery(document).ready(function() {
+					jQuery('#uploadLink').button();
+					jQuery('#createLDIFLink').button();
+				});
+				</script>
+				<?php
 			}
 		}
 		else {
-			massPrintBackButton($_POST['scope'], $selectedModules);
+			massPrintBackButton($scope, $selectedModules);
 		}
 	}
 }
 else {
 	StatusMessage('ERROR', _('Please provide a file to upload.'));
-	massPrintBackButton($_POST['scope'], $selectedModules);
+	massPrintBackButton($scope, $selectedModules);
 }
 
 echo '</div>';
@@ -226,6 +250,12 @@ function massPrintBackButton($scope, $selectedModules) {
 	$container->addElement(new htmlSpacer(null, '10px'), true);
 	$container->addElement(new htmlButton('submit', _('Back')));
 	$container->addElement(new htmlHiddenInput('type', $scope));
+	$createPDF = 0;
+	if (isset($_POST['createPDF']) && ($_POST['createPDF'] == 'on')) {
+		$createPDF = 1;
+	}
+	$container->addElement(new htmlHiddenInput('createPDF', $createPDF));
+	$container->addElement(new htmlHiddenInput('pdfStructure', $_POST['pdfStructure']));
 	for ($i = 0; $i < sizeof($selectedModules); $i++) {
 		$container->addElement(new htmlHiddenInput($scope . '_' . $selectedModules[$i], 'on'));
 	}
