@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: pdfmain.php,v 1.27 2011/04/25 18:00:47 gruberroland Exp $
+$Id: pdfmain.php,v 1.28 2012/03/20 20:44:24 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -64,7 +64,7 @@ if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
 
 // check if new template should be created
 if(isset($_POST['createNewTemplate'])) {
-	metaRefresh('pdfpage.php?type=' . $_POST['scope']);
+	metaRefresh('pdfpage.php?type=' . htmlspecialchars($_POST['scope']));
 	exit();
 }
 
@@ -110,7 +110,7 @@ for ($i = 0; $i < sizeof($templateClasses); $i++) {
 // check if a template should be edited
 for ($i = 0; $i < sizeof($templateClasses); $i++) {
 	if (isset($_POST['editTemplate_' . $templateClasses[$i]['scope']]) || isset($_POST['editTemplate_' . $templateClasses[$i]['scope'] . '_x'])) {
-		metaRefresh('pdfpage.php?type=' . $templateClasses[$i]['scope'] . '&edit=' . $_POST['template_' . $templateClasses[$i]['scope']]);
+		metaRefresh('pdfpage.php?type=' . htmlspecialchars($templateClasses[$i]['scope']) . '&edit=' . htmlspecialchars($_POST['template_' . $templateClasses[$i]['scope']]));
 		exit;
 	}
 }
