@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profilepage.php,v 1.46 2010/12/19 13:51:39 gruberroland Exp $
+$Id: profilepage.php,v 1.48 2011/05/14 13:51:08 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -178,8 +178,10 @@ $dnContent->addElement(new htmlSpacer(null, '10px'), true);
 // get root suffix
 $rootsuffix = $_SESSION['config']->get_Suffix($type);
 // get subsuffixes
-$suffixes = array();
-foreach ($_SESSION['ldap']->search_units($rootsuffix) as $suffix) {
+$suffixes = array('-' => '-');
+$typeObj = new $type();
+$possibleSuffixes = $typeObj->getSuffixList();
+foreach ($possibleSuffixes as $suffix) {
 	$suffixes[getAbstractDN($suffix)] = $suffix;
 }
 $selectedSuffix = array();
