@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: tools.php,v 1.18 2010/12/19 13:37:15 gruberroland Exp $
+$Id: tools.php,v 1.19 2011/05/19 16:25:07 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2010  Roland Gruber
+  Copyright (C) 2003 - 2011  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -70,6 +70,10 @@ for ($i = 0; $i < sizeof($tools); $i++) {
 	if ($tools[$i]->getRequiresPasswordChangeRights() && !checkIfPasswordChangeIsAllowed()) {
 		continue;
 	}
+	// check visibility
+	if (!$tools[$i]->isVisible()) {
+		continue;
+	}
 	// add tool
 	$container->addElement(new htmlLink($tools[$i]->getName(), $tools[$i]->getLink(), '../graphics/' . $tools[$i]->getImageLink()));
 	$container->addElement(new htmlSpacer('10px', null));
